scipy.spatial.KDTree
====================

.. currentmodule:: scipy.spatial

.. autoclass:: KDTree

   

   .. HACK
      .. autosummary::
         :toctree:
      
         KDTree.__init__
         KDTree.count_neighbors
         KDTree.query
         KDTree.query_ball_point
         KDTree.query_ball_tree
         KDTree.query_pairs
         KDTree.sparse_distance_matrix



   

